config() {
  NEW="$1"
  OLD="$(dirname ${NEW})/$(basename ${NEW} .new)"
  if [ ! -r ${OLD} ]; then
    mv ${NEW} ${OLD}
  elif [ "$(cat ${OLD} | md5sum)" = "$(cat ${NEW} | md5sum)" ]; then
    rm ${NEW}
  fi
}

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

config opt/netbeans/etc/netbeans.conf.new
config opt/netbeans/etc/netbeans.clusters.new
config opt/netbeans/etc/netbeans.import.new
